@@ -56,6 +56,7 @@ NULL_DATA = {poorSignalLevel:200}
 
 def _extract_tuple(data_dict):
 	"""Returns a tuple of the values extracted from a message dictionary."""
+	'GETTING CALLED BRAH'
 	return (
 		data_dict[eegPower][lowAlpha],
 		data_dict[eegPower][highAlpha],
@@ -68,12 +69,16 @@ def _extract_tuple(data_dict):
 		data_dict[poorSignalLevel],
 		data_dict[eSense][meditation],
 		data_dict[eSense][attention])
-	
-def _datastream(check_continue_func, host=HOST, port=PORT):
-	"""Create a generator that will yield the data messages being sent by the ThinkGearConnector. """
+		
+def _create_and_connect_socket(host, port):
 	cs = socket(AF_INET, SOCK_STREAM)
 	cs.connect((host, port))
 	cs.send(json.dumps(headset_conf_dict))
+	return cs
+		
+def _datastream(check_continue_func, host=HOST, port=PORT):
+	"""Create a generator that will yield the data messages being sent by the ThinkGearConnector. """
+	cs = _create_and_connect_socket(host, port)
 	data = None
 	while check_continue_func():
 		temp_json = ''
@@ -87,11 +92,13 @@ def _datastream(check_continue_func, host=HOST, port=PORT):
 		except ValueError:
 			print 'ValueError while trying to decode JSON object. discarding JSON that caused the error'
 		if data:
-			yield data
+			# build dictionary
+			ddict = dict(zip(brain_parameters, _extract_tuple(data)))
+			yield ddict
 		else:
 			continue
 	cs.close()
-	yield data
+	yield dict(zip(brain_parameters, _extract_tuple(data)))
 	
 	
 def _processDataStream(output_queue, shutdown_flag, connected_flag, host, port):
@@ -163,6 +170,7 @@ class Brain(object):
 		for p in brain_parameters:
 			header += '\t%s:\t%s\n' % (p, self.getProperty(p))
 		return header
+	
 
 #def testBrain():
 #	import code
